// Import D3 library
//import * as d3 from 'd3';

// Define the map URL and listings URL
const mapUrl =
  'https://gist.githubusercontent.com/scural/49d834b4babf26a4856bb5cc6dc37b28/raw/c4c1bbb954431897813d6295aee52668d89e199a/chicago_neigh.geojson';
//'https://gist.githubusercontent.com/scural/5eec615d4bac79e06ab40e029bd26f2d/raw/05eadcb55e39a76e9bf345c3d89f33bcf24618c2/denver_neighbourhoods.geojson';
const listingsUrl =
  'https://raw.githubusercontent.com/shamdeed30/dataSrc/main/chicago_listing_and_predictions.csv';
//'https://raw.githubusercontent.com/shamdeed30/dataSrc/main/denverAirBnbListings.csv';

// Get Data
Promise.all([d3.json(mapUrl), d3.csv(listingsUrl)])
  .then(([mapData, csvData]) => {
    // Set up SVG container
    const width = 800;
    const height = 600;

    const svg = d3
      .select('body')
      .append('svg')
      .attr('width', width)
      .attr('height', height);

    // Define projection and path generator
    const projection = d3
      .geoMercator()
      .fitSize([width, height], mapData);

    const path = d3.geoPath().projection(projection);

    // Draw map
    svg
      .selectAll('path')
      .data(mapData.features)
      .enter()
      .append('path')
      .attr('d', path)
      .attr('fill', 'lightblue')
      .attr('stroke', 'black');

    // Parse CSV data
    const parsedCsvData = csvData.map((d) => ({
      latitude: +d.latitude,
      longitude: +d.longitude,
    }));

    // Draw Airbnb listings
    svg
      .selectAll('.listing')
      .data(parsedCsvData)
      .enter()
      .append('circle')
      .attr('class', 'listing')
      .attr(
        'cx',
        (d) => projection([d.longitude, d.latitude])[0],
      )
      .attr(
        'cy',
        (d) => projection([d.longitude, d.latitude])[1],
      )
      .attr('r', 1)
      .attr('fill', 'red');
  })
  .catch((error) => {
    console.error('Error loading data:', error);
  });
